/**
 * Generated by Apache Royale Compiler from org/apache/royale/test/Assert.as
 * org.apache.royale.test.Assert
 *
 * @fileoverview
 *
 * @suppress {checkTypes|accessControls}
 */

goog.provide('org.apache.royale.test.Assert');

goog.require('org.apache.royale.test.AssertionError');
goog.require('org.apache.royale.utils.Language');



/**
 * @constructor
 */
org.apache.royale.test.Assert = function() {
};


/**
 * Asserts that the provided values are strictly equal (equivalent to
 * the <code>===</code> operator).
 * @nocollapse
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertStrictlyEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNotStrictlyEquals(actual, expected, message);
};


/**
 * Asserts that the provided values are not strictly equal (equivalent
 * to the <code>!==</code> operator).
 * @nocollapse
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNotStrictlyEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failStrictlyEquals(actual, expected, message);
};


/**
 * Asserts that the provided values are loosely equal (equivalent to
 * the <code>==</code> operator).
 * 
 * <p>Note: Type coercion may occur. For a strict comparison, without
 * type coercion, use
 * <code>assertStrictlyEquals(actual, expected, message)</code>
 * instead.</p>
 * 
 * @see Assert.assertStrictlyEquals()
 * @nocollapse
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNotEquals(actual, expected, message);
};


/**
 * Asserts that the provided values are not loosely equal (equivalent to
 * the <code>!=</code> operator).
 * 
 * <p>Note: Type coercion may occur. For a strict comparison, without
 * type coercion, use
 * <code>assertNotStrictlyEquals(actual, expected, message)</code>
 * instead.</p>
 * 
 * @see Assert.assertNotStrictlyEquals()
 * @nocollapse
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNotEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failEquals(actual, expected, message);
};


/**
 * Asserts that the provided value is true (equivalent to testing the
 * value in an <code>if(value)</code> statement).
 * 
 * <p>Note: Type coercion may occur. The assertion will pass for any
 * value that is considered <em>truthy</em>. For strict comparison to
 * true, without type coercion, use
 * <code>assertStrictlyEquals(value, true, message)</code> instead.</p>
 * @nocollapse
 * @param {*} value
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertTrue = function(value, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failFalse(value, message);
};


/**
 * Asserts that the provided value is false (equivalent to testing the
 * value in an <code>if(!value)</code> statement).
 * 
 * <p>Note: Type coercion may occur. The assertion will pass for any
 * value that is considered <em>falsy</em>. For strict comparison to
 * false, without type coercion, use
 * <code>assertStrictlyEquals(value, false, message)</code> instead.</p>
 * @nocollapse
 * @param {*} value
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertFalse = function(value, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failTrue(value, message);
};


/**
 * Asserts that the provided value is null (equivalent to testing the
 * value in an <code>if(value == null)</code> statement).
 * 
 * <p>Note: Type coercion may occur. The assertion will pass for any
 * value that is considered <em>nullish</em>. For strict comparison to
 * null, without type coercion, use
 * <code>assertStrictlyEquals(value, null, message)</code> instead.</p>
 * @nocollapse
 * @param {*} actual
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNull = function(actual, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNotNull(actual, message);
};


/**
 * Asserts that the provided value is not null (equivalent to testing
 * the value in an <code>if(value != null)</code> statement).
 * 
 * <p>Note: Type coercion may occur. The assertion will fail for any
 * value that is considered <em>nullish</em>. For strict comparison to
 * null, without type coercion, use
 * <code>assertNotStrictlyEquals(value, null, message)</code> instead.</p>
 * @nocollapse
 * @param {*} actual
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNotNull = function(actual, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNull(actual, message);
};


/**
 * Asserts that the provided value is NaN (equivalent to testing the
 * value in an <code>if(isNaN(value))</code> statement).
 * @nocollapse
 * @param {number} actual
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNaN = function(actual, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (!isNaN(actual)) {
    org.apache.royale.test.Assert.failWithUserMessage("expected NaN but was <" + actual + ">", message);
  }
};


/**
 * Asserts that the provided value is between a minimum and maximum
 * value (inclusive). Equivalent to testing the
 * value in an <code>if(value >= minimum && value <= maximum)</code>
 * statement.
 * @nocollapse
 * @param {number} actual
 * @param {number} minimum
 * @param {number} maximum
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertWithin = function(actual, minimum, maximum, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNotWithin(actual, minimum, maximum, message);
};


/**
 * Asserts that the provided value is not between a minimum and maximum
 * value (inclusive). Equivalent to testing the
 * value in an <code>if(value < minimum || value > maximum)</code>
 * statement.
 * @nocollapse
 * @param {number} actual
 * @param {number} minimum
 * @param {number} maximum
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNotWithin = function(actual, minimum, maximum, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failWithin(actual, minimum, maximum, message);
};


/**
 * Asserts that the provided value is less than another value.
 * Equivalent to testing the value in an <code>if(value < other)</code>
 * statement.
 * @nocollapse
 * @param {number} actual
 * @param {number} other
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertLessThan = function(actual, other, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failGreaterThanOrEqual(actual, other, message);
};


/**
 * Asserts that the provided value is greater than another value.
 * Equivalent to testing the value in an <code>if(value > other)</code>
 * statement.
 * @nocollapse
 * @param {number} actual
 * @param {number} other
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertGreaterThan = function(actual, other, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failLessThanOrEqual(actual, other, message);
};


/**
 * Asserts that the provided value is less or equal to than another
 * value. Equivalent to testing the value in an
 * <code>if(value <= other)</code> statement.
 * @nocollapse
 * @param {number} actual
 * @param {number} other
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertLessThanOrEqual = function(actual, other, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failGreaterThan(actual, other, message);
};


/**
 * Asserts that the provided value is greater than or equal to another
 * value. Equivalent to testing the value in an
 * <code>if(value >= other)</code> statement.
 * @nocollapse
 * @param {number} actual
 * @param {number} other
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertGreaterThanOrEqual = function(actual, other, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failLessThan(actual, other, message);
};


/**
 * Asserts that the provided value is of a type. Equivalent to testing
 * the value in an <code>if(value is type)</code> statement.
 * @nocollapse
 * @param {*} actual
 * @param {Object} type
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertType = function(actual, type, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNotType(actual, type, message);
};


/**
 * Asserts that the provided value is not of a type. Equivalent to
 * testing the value in an <code>if(!(value is type))</code> statement.
 * @nocollapse
 * @param {*} actual
 * @param {Object} type
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNotType = function(actual, type, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failType(actual, type, message);
};


/**
 * Asserts that the provided value matches a regular expression.
 * Equivalent to testing the value in an
 * <code>if(regExp.test(value))</code> statement.
 * @nocollapse
 * @param {string} actual
 * @param {RegExp} regExp
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertMatch = function(actual, regExp, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNotMatch(actual, regExp, message);
};


/**
 * Asserts that the provided value does not match a regular expression.
 * Equivalent to testing the value in an
 * <code>if(!regExp.test(value))</code> statement.
 * @nocollapse
 * @param {string} actual
 * @param {RegExp} regExp
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNotMatch = function(actual, regExp, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failMatch(actual, regExp, message);
};


/**
 * Asserts that the provided function throws.
 * 
 * <p>Equivalent to <code>[Test(expected="RangeError")]</code></p>
 * @nocollapse
 * @param {Function} fn
 * @param {Object=} type
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertThrows = function(fn, type, message) {
  type = typeof type !== 'undefined' ? type : null;
  message = typeof message !== 'undefined' ? message : null;
  try {
    fn();
  } catch (e) {
    if (type != null) {
      org.apache.royale.test.Assert.assertType(e, type, message);
    }
    return;
  }
  org.apache.royale.test.Assert.fail("expected function to throw");
};


/**
 * Fails.
 * @nocollapse
 * @param {string=} message
 * @param {Error=} sourceError
 */
org.apache.royale.test.Assert.fail = function(message, sourceError) {
  message = typeof message !== 'undefined' ? message : "";
  sourceError = typeof sourceError !== 'undefined' ? sourceError : null;
  throw new org.apache.royale.test.AssertionError(message, sourceError);
};


/**
 * Fails if the condition is true.
 * 
 * <p>Note: Type coercion may occur. The assertion will fail for any
 * value that is considered <em>truthy</em>. For strict comparison to
 * true, without type coercion, use
 * <code>failStrictlyEquals(value, true, message)</code> instead.</p>
 * @nocollapse
 * @param {*} condition
 * @param {string=} message
 */
org.apache.royale.test.Assert.failTrue = function(condition, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (condition) {
    org.apache.royale.test.Assert.failWithUserMessage("expected false but was true", message);
  }
};


/**
 * Fails if the condition is false.
 * 
 * <p>Note: Type coercion may occur. The assertion will fail for any
 * value that is considered <em>falsy</em>. For strict comparison to
 * false, without type coercion, use
 * <code>failStrictlyEquals(value, false, message)</code> instead.</p>
 * @nocollapse
 * @param {*} condition
 * @param {string=} message
 */
org.apache.royale.test.Assert.failFalse = function(condition, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (!condition) {
    org.apache.royale.test.Assert.failWithUserMessage("expected true but was false", message);
  }
};


/**
 * Fails if the values are loosely equal.
 * 
 * <p>Note: Type coercion may occur. For a strict comparison without
 * type coercion, use
 * <code>failStrictlyEquals(actual, expected, message)</code>
 * instead.</p>
 * 
 * @see Assert.failStrictlyEquals()
 * @nocollapse
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.failEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual == expected) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> not to be equal to <" + expected + ">", message);
  }
};


/**
 * Fails if the values are not loosely equal.
 * 
 * <p>Note: Type coercion may occur. For a strict comparison without
 * type coercion, use
 * <code>failNotStrictlyEquals(actual, expected, message)</code>
 * instead.</p>
 * 
 * @see Assert.failNotStrictlyEquals()
 * @nocollapse
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNotEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual != expected) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> to be equal to <" + expected + ">", message);
  }
};


/**
 * Fails if the values are strictly equal.
 * @nocollapse
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.failStrictlyEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual === expected) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> not to be strictly equal to <" + expected + ">", message);
  }
};


/**
 * Fails if the values are not strictly equal.
 * @nocollapse
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNotStrictlyEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual !== expected) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> to be strictly equal to <" + expected + ">", message);
  }
};


/**
 * Fails if the value is null.
 * 
 * <p>Note: Type coercion may occur. The assertion will fail for any
 * value that is considered <em>nullish</em>. For strict comparison
 * to null, without type coercion, use
 * <code>failStrictlyEquals(value, null, message)</code> instead.</p>
 * @nocollapse
 * @param {*} object
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNull = function(object, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (object == null) {
    org.apache.royale.test.Assert.failWithUserMessage("expected not null", message);
  }
};


/**
 * Fails if the value is not null.
 * 
 * <p>Note: Type coercion may occur. The assertion will pass for any
 * value that is considered <em>nullish</em>. For strict comparison
 * to null, without type coercion, use
 * <code>failNotStrictlyEquals(value, null, message)</code> instead.</p>
 * @nocollapse
 * @param {*} object
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNotNull = function(object, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (object != null) {
    org.apache.royale.test.Assert.failWithUserMessage("expected null: <" + object + ">", message);
  }
};


/**
 * Fails if the value is NaN.
 * @nocollapse
 * @param {number} actual
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNaN = function(actual, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (isNaN(actual)) {
    org.apache.royale.test.Assert.failWithUserMessage("expected not NaN: <" + actual + ">", message);
  }
};


/**
 * Fails if the provided value is between a minimum and maximum value
 * (inclusive).
 * @nocollapse
 * @param {number} actual
 * @param {number} minimum
 * @param {number} maximum
 * @param {string=} message
 */
org.apache.royale.test.Assert.failWithin = function(actual, minimum, maximum, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual >= minimum && actual <= maximum) {
    org.apache.royale.test.Assert.failWithUserMessage("expected not between <" + minimum + "> and <" + maximum + "> but was <" + actual + ">", message);
  }
};


/**
 * Fails if the provided value is not between a minimum and maximum
 * value (inclusive).
 * @nocollapse
 * @param {number} actual
 * @param {number} minimum
 * @param {number} maximum
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNotWithin = function(actual, minimum, maximum, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual < minimum || actual > maximum) {
    org.apache.royale.test.Assert.failWithUserMessage("expected between <" + minimum + "> and <" + maximum + "> but was <" + actual + ">", message);
  }
};


/**
 * Fails if the provided value is less than another value.
 * @nocollapse
 * @param {number} actual
 * @param {number} other
 * @param {string=} message
 */
org.apache.royale.test.Assert.failLessThan = function(actual, other, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual < other) {
    org.apache.royale.test.Assert.failWithUserMessage("expected greater than or equal to <" + other + "> but was <" + actual + ">", message);
  }
};


/**
 * Fails if the provided value is greater than another value.
 * @nocollapse
 * @param {number} actual
 * @param {number} other
 * @param {string=} message
 */
org.apache.royale.test.Assert.failGreaterThan = function(actual, other, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual > other) {
    org.apache.royale.test.Assert.failWithUserMessage("expected less than or equal to <" + other + "> but was <" + actual + ">", message);
  }
};


/**
 * Fails if the provided value is less than or equal to another value.
 * @nocollapse
 * @param {number} actual
 * @param {number} other
 * @param {string=} message
 */
org.apache.royale.test.Assert.failLessThanOrEqual = function(actual, other, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual <= other) {
    org.apache.royale.test.Assert.failWithUserMessage("expected greater than <" + other + "> but was <" + actual + ">", message);
  }
};


/**
 * Fails if the provided value is greater than or equal to another
 * value.
 * @nocollapse
 * @param {number} actual
 * @param {number} other
 * @param {string=} message
 */
org.apache.royale.test.Assert.failGreaterThanOrEqual = function(actual, other, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual >= other) {
    org.apache.royale.test.Assert.failWithUserMessage("expected less than <" + other + "> but was <" + actual + ">", message);
  }
};


/**
 * Fails if the provided value is of a type.
 * @nocollapse
 * @param {*} actual
 * @param {Object} type
 * @param {string=} message
 */
org.apache.royale.test.Assert.failType = function(actual, type, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (org.apache.royale.utils.Language.is(actual, type)) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> to not be of type <" + type + ">", message);
  }
};


/**
 * Fails if the provided value is not of a type.
 * @nocollapse
 * @param {*} actual
 * @param {Object} type
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNotType = function(actual, type, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (!org.apache.royale.utils.Language.is(actual, type)) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> to be of type <" + type + ">", message);
  }
};


/**
 * Fails if the provided value matches a regular expression.
 * @nocollapse
 * @param {string} actual
 * @param {RegExp} regExp
 * @param {string=} message
 */
org.apache.royale.test.Assert.failMatch = function(actual, regExp, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (regExp.test(actual)) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> to match regular expression <" + regExp + ">", message);
  }
};


/**
 * Fails if the provided value does not match a regular expression.
 * @nocollapse
 * @param {string} actual
 * @param {RegExp} regExp
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNotMatch = function(actual, regExp, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (!regExp.test(actual)) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> not to match regular expression <" + regExp + ">", message);
  }
};


/**
 * Fails if the provided function throws.
 * @nocollapse
 * @param {Function} fn
 * @param {Object=} type
 * @param {string=} message
 */
org.apache.royale.test.Assert.failThrows = function(fn, type, message) {
  type = typeof type !== 'undefined' ? type : null;
  message = typeof message !== 'undefined' ? message : null;
  try {
    fn();
  } catch (e) {
    if (type != null && org.apache.royale.utils.Language.is(e, type)) {
      org.apache.royale.test.Assert.fail("expected function not to throw type <" + type + ">");
      return;
    }
    org.apache.royale.test.Assert.fail("expected function not to throw");
  }
};


/**
 * @asprivate
 * @protected
 * @nocollapse
 * @param {string} userMessage
 * @param {string=} failMessage
 */
org.apache.royale.test.Assert.failWithUserMessage = function(userMessage, failMessage) {
  failMessage = typeof failMessage !== 'undefined' ? failMessage : null;
  if (failMessage) {
    throw new org.apache.royale.test.AssertionError(userMessage + " - " + failMessage);
  }
  throw new org.apache.royale.test.AssertionError(userMessage);
};


/**
 * Metadata
 *
 * @type {Object.<string, Array.<Object>>}
 */
org.apache.royale.test.Assert.prototype.ROYALE_CLASS_INFO = { names: [{ name: 'Assert', qName: 'org.apache.royale.test.Assert', kind: 'class' }] };



/**
 * Reflection
 *
 * @return {Object.<string, Function>}
 */
org.apache.royale.test.Assert.prototype.ROYALE_REFLECTION_INFO = function () {
  return {
    methods: function () {
      return {
        '|assertStrictlyEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|assertNotStrictlyEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|assertEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|assertNotEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|assertTrue': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|assertFalse': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|assertNull': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|assertNotNull': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|assertNaN': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'String', true ]; }},
        '|assertWithin': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'Number', false ,'String', true ]; }},
        '|assertNotWithin': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'Number', false ,'String', true ]; }},
        '|assertLessThan': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'String', true ]; }},
        '|assertGreaterThan': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'String', true ]; }},
        '|assertLessThanOrEqual': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'String', true ]; }},
        '|assertGreaterThanOrEqual': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'String', true ]; }},
        '|assertType': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'Class', false ,'String', true ]; }},
        '|assertNotType': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'Class', false ,'String', true ]; }},
        '|assertMatch': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'String', false ,'RegExp', false ,'String', true ]; }},
        '|assertNotMatch': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'String', false ,'RegExp', false ,'String', true ]; }},
        '|assertThrows': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Function', false ,'Class', true ,'String', true ]; }},
        '|fail': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'String', true ,'Error', true ]; }},
        '|failTrue': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|failFalse': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|failEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|failNotEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|failStrictlyEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|failNotStrictlyEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|failNull': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|failNotNull': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|failNaN': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'String', true ]; }},
        '|failWithin': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'Number', false ,'String', true ]; }},
        '|failNotWithin': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'Number', false ,'String', true ]; }},
        '|failLessThan': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'String', true ]; }},
        '|failGreaterThan': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'String', true ]; }},
        '|failLessThanOrEqual': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'String', true ]; }},
        '|failGreaterThanOrEqual': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Number', false ,'Number', false ,'String', true ]; }},
        '|failType': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'Class', false ,'String', true ]; }},
        '|failNotType': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'Class', false ,'String', true ]; }},
        '|failMatch': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'String', false ,'RegExp', false ,'String', true ]; }},
        '|failNotMatch': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'String', false ,'RegExp', false ,'String', true ]; }},
        '|failThrows': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'Function', false ,'Class', true ,'String', true ]; }}
      };
    }
  };
};
/**
 * @const
 * @type {number}
 */
org.apache.royale.test.Assert.prototype.ROYALE_COMPILE_FLAGS = 10;